# Konza Prairie - Dispersal Analysis
# GRSPnests.R

rm(list=ls())	
library(RMark)
library(Hmisc)

# input file
# Names of dates and fate have to be exactly right for RMark
GRSPnests = read.csv(file.choose())
head(GRSPnests,20)

# adjust dates for nest survival
(min = min(GRSPnests$FirstFound))  # needs to be 1 for dataset
(occ = max(GRSPnests$LastChecked))

# Treat dummy variables as factors
GRSPnests$Year=factor(GRSPnests$Year)
GRSPnests$Parasitized=factor(GRSPnests$Parasitized)
GRSPnests$GrazingTrt=factor(GRSPnests$GrazingTrt)
GRSPnests$BurnedThisYear=factor(GRSPnests$BurnedThisYear)
GRSPnests$Watershed=factor(GRSPnests$Watershed)
GRSPnests$NestOrder=factor(GRSPnests$Attempt)
GRSPnests$DispersalStatus=factor(GRSPnests$DispersalStatus)

#look at data, make sure levels are correct
levels(GRSPnests$DispersalStatus)
levels(GRSPnests$Year)
levels(GRSPnests$Parasitized)
levels(GRSPnests$BurnedThisYear)
levels(GRSPnests$Attempt)
levels(GRSPnests$GrazingTrt)
GRSPnests$GrazingTrt


#### NEST SURVIVAL 
###############################

# Write a function for evaluating a set of competing models
run.GRSPnests=function()
{
  
  # A model of constant daily survival rate (DSR)
  Dot=mark(GRSPnests,nocc=occ,model="Nest",model.parameters=list(S=list(formula=~1)))
  
  # DSR varies by year
  Year=mark(GRSPnests,nocc=occ,model="Nest",
            model.parameters=list(S=list(formula=~Year)), groups="Year")
  
  # DSR varies by dispersal status
  DispersalStatus=mark(GRSPnests,nocc=occ,model="Nest",
                       model.parameters=list(S=list(formula=~DispersalStatus)), groups="DispersalStatus")
  
  # DSR varies by GrazingTrt
  GrazingTrt=mark(GRSPnests,nocc=occ,model="Nest",
                  model.parameters=list(S=list(formula=~GrazingTrt)), groups="GrazingTrt")
  
  # DSR varies by year and grazing 
  GrazeYear=mark(GRSPnests,nocc=occ,model="Nest",
                 model.parameters=list(S=list(formula=~Year+GrazingTrt)), groups=c("Year","GrazingTrt"))
  
  # DSR varies by grazing, year, and interaction
  GrazeYearInt=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~GrazingTrt+Year+GrazingTrt*Year)), groups=c("GrazingTrt", "Year"))
 
   #DSR varies by grazing, year, dispersal status, and interaction b/t year and grazing
  GrazeYearDispInt=mark(GRSPnests,nocc=occ,model="Nest",
                    model.parameters=list(S=list(formula=~GrazingTrt+Year+DispersalStatus+GrazingTrt*Year)), groups=c("GrazingTrt", "Year", "DispersalStatus"))
  # Return model table and list of models
  return(collect.models() )
}

GRSPnests.results=run.GRSPnests() # This runs the models above and takes a minute or 2
GRSPnests.results # print model selection table to screen
# Look for STOP NORMAL EXIT message after each model

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine table of model selection results 
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#

options(width=100) # set page width to 100 characters
sink("results.table.txt") # capture screen output to file
print.marklist(GRSPnests.results) # send output to file
sink() # return output to screen
system("notepad results.table.txt",invisible=FALSE)

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for constant DSR model #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$Dot$results$real # view estimated beta for model in R
#GRSPnests.results$Dot # print MARK output to designated text editor

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for Year model             #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$Year$results$real # view the estimates of Daily Survival Rate
#GRSPnests.results$Year # print MARK output to designated text editor

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for GrazingTrt model       #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$GrazingTrt$results$real # view the estimates of Daily Survival Rate
#PBGnests.results$GrazingTrt # print MARK output to designated text editor

GRSPnests.results$GrazingTrt$results$beta

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for Grazing Trt + Year Mgmt model  #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#

GRSPnests.results$GrazeYear$results$real # view the estimates of Daily Survival Rate
#GRSPnests.results$GrazeYear # print MARK output to designated text editor

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for DispersalStatus model  #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$DispersalStatus$results$real # view the estimates of Daily Survival Rate
GRSPnests.results$DispersalStatus # print MARK output to designated text editor

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for Grazing Trt*Year model #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$GrazeYearInt$results$real # view the estimates of Daily Survival Rate
#GRSPnests.results$GrazeYearInt # print MARK output to designated text editor

#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
# Examine output for Dispersal Status + Grazing Trt*Year model  #
#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~#
GRSPnests.results$GrazeYearDispInt$results$real # view the estimates of Daily Survival Rate
GRSPnests.results$GrazeYearDispInt # print MARK output to designated text editor


GRSPnests.results$GrazeYearDispInt$results$beta
